.. _configaro_releases:

=============
Release Notes
=============

.. _configaro_release_1_0_1:

1.0.1
=====

Changes
-------

- documentation changes only

.. _configaro_release_1_0_0:

1.0.0
=====

Initial release of **configaro**, a Python 3.6 configuration library that's
music to your ears.

Features
~~~~~~~~

- a single file library with minimal dependencies
- a simple, expressive API that is easy to use and gets out of your way
- one that allows for hierarchical config data with dot-addressable access
- one that allows for defaults and locals config modules
- project automation, documentation and test coverage

